@@ -1,14 +1,13 @@
 import logging
-from typing import Optional, Iterable
+from typing import Optional
 from . import util
 
 
 class Plugin:
-    def __init__(self, pipeline: str, job_id: int, args: Optional[dict] = None, data_key: Optional[str] = None):
+    def __init__(self, pipeline: str, job_id: int, args: Optional[dict] = None):
         self.pipeline = pipeline
         self.job_id = job_id
         self.args = args if args is not None else {}
-        self.data_key = data_key
 
         self.logger = PluginLoggerAdapter(util.get_class_logger(self), self.pipeline, self.job_id)
 
@@ -17,8 +16,10 @@ class Plugin:
 
 
 class Trigger:
-    def __init__(self, pipeline: str):
+    def __init__(self, pipeline: str, args: Optional[dict] = None):
         self.pipeline = pipeline
+        self.args = args if args is not None else {}
+
         self.logger = TriggerLoggerAdapter(util.get_class_logger(self), self.pipeline)
 
     def run(self):
